package com.hungraim.ltc.facelocation.util;

import com.hungraim.ltc.pojo.entity.serviceManage.ChSrvOrganEmp;
import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.Credential;
import com.tencentcloudapi.common.profile.ClientProfile;
import com.tencentcloudapi.common.profile.HttpProfile;
import com.tencentcloudapi.iai.v20200303.IaiClient;
import com.tencentcloudapi.iai.v20200303.models.*;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.Base64;
import com.hungraim.ltc.util.Result;
/**
 * <pre>
 * 人脸核身代码
 * </pre>
 */
@Slf4j
@Configuration
public class FaceAuthUtil {

    @Autowired
    private FaceAuthProperties faceAuthProperties;

    public Result<String> addFace(ChSrvOrganEmp faceAuthParam,String filePath){

         try {
             //设置文件路径
             // 实例化一个认证对象，入参需要传入腾讯云账户 SecretId 和 SecretKey
             Credential cred = new Credential(faceAuthProperties.getSecretId(), faceAuthProperties.getSecretKey());
             // 实例化一个http选项，可选的，没有特殊需求可以跳过
             HttpProfile httpProfile = new HttpProfile();
             httpProfile.setEndpoint(faceAuthProperties.getUrlPath());
             // 实例化一个client选项，可选的，没有特殊需求可以跳过
             ClientProfile clientProfile = new ClientProfile();
             clientProfile.setHttpProfile(httpProfile);
             // 实例化要请求产品的client对象,clientProfile是可选的
             IaiClient client = new IaiClient(cred, faceAuthProperties.getRegion(), clientProfile);
             // 实例化一个请求对象,每个接口都会对应一个request对象
             CreatePersonRequest req = new CreatePersonRequest();
             req.setGroupId(faceAuthProperties.getGroupId());
             req.setPersonName(faceAuthParam.getEmpName());
             req.setPersonId(faceAuthParam.getCertifNum());
             if(faceAuthParam.getGender().equals("M")){
                 req.setGender(1l);
             }else if(faceAuthParam.getGender().equals("F")){
                 req.setGender(2l);
             }else{
                 req.setGender(0l);
             }
             log.info("personName:::::"+faceAuthParam.getEmpName());
             log.info("personId:::::"+faceAuthParam.getCertifNum());
             log.info("gender:::::"+req.getGender());
             log.info("照片base:::::"+imageToBase64(filePath));
             req.setImage(imageToBase64(filePath));
             CreatePersonResponse resp = client.CreatePerson(req);
             log.info("腾讯云返回:"+AbstractModel.toJsonString(resp));
             return Result.success(resp.getFaceId());
            } catch (
            Exception e) {
               log.error(e.toString());
               return Result.failed(e.getMessage());
            }
    }

    public  String imageToBase64(String imagePath) {
        String base64String = "";
        File file = new File(imagePath);
        try (FileInputStream fileInputStream = new FileInputStream(file)) {
            byte[] bytes = new byte[(int) file.length()];
            fileInputStream.read(bytes);
            base64String = Base64.getEncoder().encodeToString(bytes);
        } catch (IOException e) {
            e.printStackTrace();
        }
        return base64String;
    }



    public  Result<String> deleteFace(ChSrvOrganEmp faceAuthParam){

        try {
            // 实例化一个认证对象，入参需要传入腾讯云账户 SecretId 和 SecretKey
            Credential cred = new Credential(faceAuthProperties.getSecretId(), faceAuthProperties.getSecretKey());
            // 实例化一个http选项，可选的，没有特殊需求可以跳过
            HttpProfile httpProfile = new HttpProfile();
            httpProfile.setEndpoint(faceAuthProperties.getUrlPath());

            // 实例化一个client选项，可选的，没有特殊需求可以跳过
            ClientProfile clientProfile = new ClientProfile();
            clientProfile.setHttpProfile(httpProfile);
            // 实例化要请求产品的client对象,clientProfile是可选的
            IaiClient client = new IaiClient(cred, faceAuthProperties.getRegion(), clientProfile);
            // 实例化一个请求对象,每个接口都会对应一个request对象
            DeleteFaceRequest req = new DeleteFaceRequest();
            req.setPersonId(faceAuthParam.getCertifNum());

            String[] faceIds1 = {faceAuthParam.getFaceId()};//人脸
            req.setFaceIds(faceIds1);

            // 返回的resp是一个DeleteFaceResponse的实例，与请求对象对应
            DeleteFaceResponse resp = client.DeleteFace(req);
            // 输出json格式的字符串回包
            System.out.println(AbstractModel.toJsonString(resp));

            // 输出json格式的字符串回包
            return Result.success(resp.getRequestId());

        } catch (Exception e) {
            log.error(e.toString());
            return Result.failed(e.getMessage());
        }
    }
}
